@@ -2,10 +2,8 @@ require 'spec_helper_acceptance'
 require_relative './version.rb'
 
 describe 'apache ssl' do
-
   describe 'ssl parameters' do
-    it 'runs without error' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         class { 'apache':
           service_ensure        => stopped,
           default_ssl_vhost     => true,
@@ -17,8 +15,10 @@ describe 'apache ssl' do
           default_ssl_crl       => '/tmp/ssl_crl',
           default_ssl_crl_check => 'chain',
         }
-      EOS
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'runs without error' do
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{$vhost_dir}/15-default-ssl.conf") do
@@ -26,11 +26,11 @@ describe 'apache ssl' do
       it { is_expected.to contain 'SSLCertificateFile      "/tmp/ssl_cert"' }
       it { is_expected.to contain 'SSLCertificateKeyFile   "/tmp/ssl_key"' }
       it { is_expected.to contain 'SSLCertificateChainFile "/tmp/ssl_chain"' }
-      it { is_expected.to contain 'SSLCACertificateFile    "/tmp/ssl_ca"' }
-      it { is_expected.to contain 'SSLCARevocationPath     "/tmp/ssl_crl_path"' }
-      it { is_expected.to contain 'SSLCARevocationFile     "/tmp/ssl_crl"' }
+      it { is_expected.not_to contain 'SSLCACertificateFile    "/tmp/ssl_ca"' }
+      it { is_expected.not_to contain 'SSLCARevocationPath     "/tmp/ssl_crl_path"' }
+      it { is_expected.not_to contain 'SSLCARevocationFile     "/tmp/ssl_crl"' }
       if $apache_version == '2.4'
-        it { is_expected.to contain 'SSLCARevocationCheck    "chain"' }
+        it { is_expected.not_to contain 'SSLCARevocationCheck    "chain"' }
       else
         it { is_expected.not_to contain 'SSLCARevocationCheck' }
       end
@@ -38,8 +38,7 @@ describe 'apache ssl' do
   end
 
   describe 'vhost ssl parameters' do
-    it 'runs without error' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         class { 'apache':
           service_ensure       => stopped,
         }
@@ -64,8 +63,10 @@ describe 'apache ssl' do
           ssl_proxyengine      => true,
           ssl_proxy_protocol   => 'TLSv1.2',
         }
-      EOS
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'runs without error' do
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{$vhost_dir}/25-test_ssl.conf") do
@@ -74,6 +75,7 @@ describe 'apache ssl' do
       it { is_expected.to contain 'SSLCertificateKeyFile   "/tmp/ssl_key"' }
       it { is_expected.to contain 'SSLCertificateChainFile "/tmp/ssl_chain"' }
       it { is_expected.to contain 'SSLCACertificateFile    "/tmp/ssl_ca"' }
+      it { is_expected.to contain 'SSLCACertificatePath    "/tmp"' }
       it { is_expected.to contain 'SSLCARevocationPath     "/tmp/ssl_crl_path"' }
       it { is_expected.to contain 'SSLCARevocationFile     "/tmp/ssl_crl"' }
       it { is_expected.to contain 'SSLProxyEngine On' }
@@ -91,4 +93,62 @@ describe 'apache ssl' do
     end
   end
 
+  describe 'vhost ssl ssl_ca only' do
+    pp = <<-MANIFEST
+        class { 'apache':
+          service_ensure       => stopped,
+        }
+
+        apache::vhost { 'test_ssl_ca_only':
+          docroot              => '/tmp/test',
+          ssl                  => true,
+          ssl_cert             => '/tmp/ssl_cert',
+          ssl_key              => '/tmp/ssl_key',
+          ssl_ca               => '/tmp/ssl_ca',
+          ssl_verify_client    => 'test',
+        }
+    MANIFEST
+    it 'runs without error' do
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
+    end
+
+    describe file("#{$vhost_dir}/25-test_ssl_ca_only.conf") do
+      it { is_expected.to be_file }
+      it { is_expected.to contain 'SSLCertificateFile      "/tmp/ssl_cert"' }
+      it { is_expected.to contain 'SSLCertificateKeyFile   "/tmp/ssl_key"' }
+      it { is_expected.to contain 'SSLCACertificateFile    "/tmp/ssl_ca"' }
+      it { is_expected.not_to contain 'SSLCACertificatePath' }
+    end
+  end
+
+  describe 'vhost ssl ssl_certs_dir' do
+    pp = <<-MANIFEST
+        class { 'apache':
+          service_ensure       => stopped,
+        }
+
+        apache::vhost { 'test_ssl_certs_dir_only':
+          docroot              => '/tmp/test',
+          ssl                  => true,
+          ssl_cert             => '/tmp/ssl_cert',
+          ssl_key              => '/tmp/ssl_key',
+          ssl_certs_dir        => '/tmp',
+          ssl_verify_client    => 'test',
+        }
+    MANIFEST
+    it 'runs without error' do
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
+    end
+
+    describe file("#{$vhost_dir}/25-test_ssl_certs_dir_only.conf") do
+      it { is_expected.to be_file }
+      it { is_expected.to contain 'SSLCertificateFile      "/tmp/ssl_cert"' }
+      it { is_expected.to contain 'SSLCertificateKeyFile   "/tmp/ssl_key"' }
+      it { is_expected.to contain 'SSLCACertificatePath    "/tmp"' }
+      it { is_expected.to contain 'SSLVerifyClient         test' }
+      it { is_expected.not_to contain 'SSLCACertificateFile' }
+    end
+  end
 end
